@@ -1,7 +1,7 @@
 package Net::SMS::CDYNE;
 
 use 5.008_001;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Any::Moose;
 use Any::Moose 'X::NonMoose';
@@ -62,6 +62,10 @@ sub do_cdyne_request {
     my $resp_obj = eval { XMLin($content) };
     warn "Failed parsing response: $content ($@)" unless $resp_obj;
 
+    # if we do an advanced send, we get an array of responses.
+    # since we only handle sending one message at a time, we can just grab the first response.
+    $resp_obj = $resp_obj->{SMSResponse} if $resp_obj->{SMSResponse};
+
     my $ret = {
         response_code => $response_code,
         %$resp_obj,
